News
====

Lists of changes between versions.

Latest
------
* Major:
* Minor:
* Patch:


1.0.0
-----
* Minor: Tested on Windows (excluding 'safety check').
* Minor: Added logging (use --log-level and --log-file).

0.2.0
-----
* Minor: Tested on MacOs.
* Minor: Warn instead of assert if shell==True in run.
* Patch: Fixed used of prefix in check_for_test_files.
* Patch: Fixed repository_name function.

0.1.0
-----
* Minor: Added checks during release.

0.0.5
-----
* Minor: Added security vulnerabilities check using 'safety'.
* Minor: Added docstrings check using 'flake8-docstrings'.
* Minor: Git releated functionality moved to bouillon.git.*

0.0.1
-----
* Initial release.
